import ttkbootstrap as tb
from ttkbootstrap.constants import *
from tkinter import messagebox
import requests  # Import requests for API communication

def register_frame(parent, switch_func, api_url):  # Added api_url parameter
    frame = tb.Frame(parent)

    def register():
        username = entry_username.get()
        email = entry_email.get()
        phone_number = entry_phone.get()
        password = entry_password.get()
        confirm_password = entry_confirm_password.get()

        if not username or not email or not phone_number or not password or not confirm_password:
            messagebox.showwarning("Input Error", "All fields are required!")
            return

        if password != confirm_password:
            messagebox.showerror("Password Error", "Passwords do not match!")
            return

        # Sending registration data to backend
        response = requests.post(f"{api_url}/auth/signup", json={
            "username": username,
            "email": email,
            "phone_number": phone_number,
            "password": password
        })

        try:
            response_data = response.json()
            if response.status_code == 200:
                messagebox.showinfo("Registration Successful", f"Welcome, {username}!")
                switch_func("login")  # Switch to login after successful registration
            else:
                messagebox.showerror("Registration Failed", response_data.get("detail", "Unknown error"))
        except requests.exceptions.JSONDecodeError:
            messagebox.showerror("Registration Failed", f"Server returned an invalid response.")

    tb.Label(frame, text="Register", font=("Helvetica", 18, "bold")).pack(pady=10)

    tb.Label(frame, text="Username:").pack(pady=5)
    entry_username = tb.Entry(frame, bootstyle="info")
    entry_username.pack(pady=5)

    tb.Label(frame, text="Email:").pack(pady=5)
    entry_email = tb.Entry(frame, bootstyle="info")
    entry_email.pack(pady=5)

    tb.Label(frame, text="Phone Number:").pack(pady=5)
    entry_phone = tb.Entry(frame, bootstyle="info")
    entry_phone.pack(pady=5)

    tb.Label(frame, text="Password:").pack(pady=5)
    entry_password = tb.Entry(frame, bootstyle="info", show="*")
    entry_password.pack(pady=5)

    tb.Label(frame, text="Confirm Password:").pack(pady=5)
    entry_confirm_password = tb.Entry(frame, bootstyle="info", show="*")
    entry_confirm_password.pack(pady=5)

    btn_register = tb.Button(frame, text="Register", bootstyle="success", command=register)
    btn_register.pack(pady=15)

    tb.Button(frame, text="Already have an account? Login", bootstyle="link",
              command=lambda: switch_func("login")).pack()

    return frame
